@@ -37,7 +37,7 @@ class TamingDecoder(ImageGenerator):
         if not os.path.exists(modeling_ckpt_path):
             logging.info("Downloading pre-trained weights for VQ-GAN")
             os.system(
-                f"wget 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1' -O '{modeling_ckpt_path}'"
+                f"curl -LO 'https://heibox.uni-heidelberg.de/f/867b05fc8c4841768640/?dl=1' -o '{modeling_ckpt_path}'"
             )
 
         # TODO: update the url with our own config using the correct paths
@@ -45,7 +45,7 @@ class TamingDecoder(ImageGenerator):
         if not os.path.exists(modeling_config_path):
             logging.info("Downloading `model.yaml` from vipermu taming-transformers fork")
             os.system(
-                f"wget 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml' -O '{modeling_config_path}'"
+                f"curl -LO 'https://raw.githubusercontent.com/vipermu/taming-transformers/master/configs/custom_vqgan.yaml' -o '{modeling_config_path}'"
             )
 
         vqgan_config_xl = self.load_config(
